@@ -198,9 +198,9 @@ bool DatetimeDBusProxy::GetZoneInfo(const QString &zone, QObject *receiver, cons
 }
 
 // System Timedate
-void DatetimeDBusProxy::SetTimezone(const QString &timezone)
+QDBusPendingCall DatetimeDBusProxy::SetTimezone(const QString &timezone, const QString &message)
 {
-    m_timedateInter->asyncCall(QStringLiteral("SetTimezone"), timezone);
+    return m_systemtimedatedInter->asyncCall(QStringLiteral("SetTimezone"), timezone, message);
 }
 
 void DatetimeDBusProxy::SetNTPServer(const QString &server, const QString &message)
