@@ -51,7 +51,7 @@ class DatetimeModel : public QObject
 
     Q_PROPERTY(QString digitGroupingSymbol READ digitGroupingSymbol WRITE setDigitGroupingSymbol NOTIFY digitGroupingSymbolChanged FINAL)
     Q_PROPERTY(int langState READ langState NOTIFY langStateChanged FINAL)
-    Q_PROPERTY(QString numberExampleFormat READ numberExampleFormat NOTIFY numberExampleFormatChanged FINAL)
+    Q_PROPERTY(QStringList numberExampleParts READ numberExampleParts NOTIFY numberExampleFormatChanged FINAL)
 
 public:
     using Regions = QMap<QString, QLocale>;
@@ -167,7 +167,7 @@ public:
     void setWeekdayFormat(int newWeekdayFormat);
     int langState() const;
 
-    QString numberExampleFormat() const;
+    QStringList numberExampleParts() const;
 
 Q_SIGNALS:
     void ntpChanged(bool value);
@@ -208,7 +208,7 @@ Q_SIGNALS:
     void currentTimeChanged();
     void currentFormatChanged(int format);
     void langStateChanged(int state);
-    void numberExampleFormatChanged(const QString &numberExampleFormat);
+    void numberExampleFormatChanged(const QStringList &numberExampleParts);
 
 public Q_SLOTS:
     void set24HourFormat(bool state);
@@ -249,9 +249,31 @@ public Q_SLOTS:
     QString currentDate();
     QString currentTime() const;
     QString getCustomNtpServer() const;
+
+    // 符号冲突检测功能
+    bool hasSymbolConflict() const;
+    QStringList getAllSupportedSymbols() const;
+    
+    // 自动冲突解决功能
+    void resolveSymbolConflict();
+    
+    // UI符号列表过滤功能
+    QStringList getFilteredDecimalSymbols() const;
+    QStringList getFilteredSeparatorSymbols() const;
+    
+    // 中文区域默认设置功能
+    bool isChineseLocale() const;
+    void applyChineseDefaults();
+
 protected:
     void initModes(const QStringList &names, int indexBegin, int indexEnd, QAbstractListModel *model);
+
+    // 符号冲突检测方法（供DatetimeWorker使用）
+    bool symbolsConflict(const QString &decimal, const QString &separator) const;
+
 private:
+    // 自动冲突解决私有方法
+    QString resolveDecimalSymbol(const QString &decimal, const QString &separator) const;
     bool m_ntp;
     bool m_bUse24HourType;
     QStringList m_userZoneIds;
