@@ -51,7 +51,7 @@ KeyboardController::KeyboardController(QObject *parent)
                     return;
                 }
 
-                auto conflictName = QString("<font color=\"red\">%1</font>").arg(conflict->name);
+                auto conflictName = QString("<font color=\"red\">%1</font>").arg(conflict->name.toHtmlEscaped());
                 QString text = KeyboardController::tr("This shortcut conflicts with [%1]").arg(conflictName);
                 setConflictText(text);
                 Q_EMIT keyConflicted(current ? current->accels : "", conflict->accels);
@@ -364,6 +364,30 @@ bool KeyboardController::isCustomShortcutNameExists(const QString &name, const Q
     return false;
 }
 
+bool KeyboardController::isSystemShortcutNameExists(const QString &name)
+{
+    if (!m_shortcutModel) {
+        return false;
+    }
+    
+    return m_shortcutModel->containsSystemShortcutName(name);
+}
+
+bool KeyboardController::isShortcutNameExists(const QString &name, const QString &excludeId)
+{
+    if (name.trimmed().isEmpty()) {
+        return false;
+    }
+    
+    // 优先检查系统快捷键冲突
+    if (isSystemShortcutNameExists(name)) {
+        return true;
+    }
+    
+    // 然后检查自定义快捷键冲突
+    return isCustomShortcutNameExists(name, excludeId);
+}
+
 }
 
 #include "keyboardcontroller.moc"
