@@ -14,6 +14,7 @@
 #include <QDir>
 #include <QTimer>
 #include <QProcessEnvironment>
+#include "QCoreApplication"
 
 #include "applet.h"
 #include <dsglobal.h>
@@ -22,6 +23,7 @@
 #include <appletbridge.h>
 
 #include <polkit-qt6-1/PolkitQt1/Authority>
+#include <qnamespace.h>
 
 Q_DECLARE_LOGGING_CATEGORY(DCC_PRIVACY)
 static const QString DESKTOP_ENTRY_ICON_KEY = "Desktop Entry";
@@ -51,7 +53,11 @@ void PrivacySecurityWorker::init()
     if (!m_pathList.isEmpty())
         return;
     m_dataProxy->init();
-    initApp();
+    // TODO：由于控制中心通过子线程加载插件后，会移动插件的加载线程->主线程，
+    // 并删除原有线程->未指定父的对象所处的线程会被删除，所以使用qApp->主线程调用initApp
+    QMetaObject::invokeMethod(qApp, [this]() {
+        initApp();
+    }, Qt::BlockingQueuedConnection);
 
     connect(m_model, &PrivacySecurityModel::requestUpdateCacheBlacklist, this, &PrivacySecurityWorker::updateCacheBlacklist);
 
@@ -100,6 +106,16 @@ void PrivacySecurityWorker::initApp()
                 addAppItem(i);
             }
         });
+        connect(model, &QAbstractItemModel::rowsAboutToBeRemoved, this, [this](const QModelIndex &parent, int first, int last)
+        {
+            Q_UNUSED(parent)
+            for (int i = last; i >= first; i--) {
+                QString appId = m_ddeAmModel->data(m_ddeAmModel->index(i, 0), DS_NAMESPACE::AppItemModel::IdRole).toString();
+                if (!appId.isEmpty()) {
+                    m_model->removeApplictionItem(appId);
+                }
+            }
+        }, Qt::DirectConnection);
     }
 }
 
@@ -345,9 +361,9 @@ ApplicationItem *PrivacySecurityWorker::addAppItem(int dataIndex)
     ApplicationItem *appItem = new ApplicationItem();
     appItem->onIdChanged(id);
     appItem->onNameChanged(name);
+    appItem->onIconChanged(iconName);
     appItem->onExecsChanged(execs);
     if (m_model->addApplictionItem(appItem)) {
-        appItem->onIconChanged(iconName);
         m_model->updatePermission(appItem);
 
         updateAppPath(appItem);
